package com.muyu.networking.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.domain.FaultCode;
import com.muyu.domain.req.FaultCodeEditReq;
import com.muyu.domain.req.FaultCodeQueryReq;
import com.muyu.domain.req.FaultCodeSaveReq;
import com.muyu.networking.service.FaultCodeService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;


/**
 * 车辆故障码Controller
 *
 * @author chx
 * @date 2024-06-20
 */
@Api(tags = "车辆故障码")
@RestController
@RequestMapping("/faultCode")
public class FaultCodeController extends BaseController {
    @Autowired
    private FaultCodeService faultCodeService;

    /**
     * 查询车辆故障码列表
     */
    @ApiOperation("获取车辆故障码列表")
    @RequiresPermissions("client:faultCode:list")
    @GetMapping("/list")
    public Result<TableDataInfo<FaultCode>> list(FaultCodeQueryReq faultCodeQueryReq) {
        startPage();
        List<FaultCode> list = faultCodeService.list(FaultCode.queryBuild(faultCodeQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出车辆故障码列表
     */
    @ApiOperation("导出车辆故障码列表")
    @RequiresPermissions("client:faultCode:export")
    @Log(title = "车辆故障码", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaultCode faultCode) {
        List<FaultCode> list = faultCodeService.list(faultCode);
        ExcelUtil<FaultCode> util = new ExcelUtil<FaultCode>(FaultCode.class);
        util.exportExcel(response, list, "车辆故障码数据");
    }

    /**
     * 获取车辆故障码详细信息
     */
    @ApiOperation("获取车辆故障码详细信息")
    @RequiresPermissions("client:faultCode:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<FaultCode> getInfo(@PathVariable("id") Long id) {
        return Result.success(faultCodeService.getById(id));
    }

    /**
     * 新增车辆故障码
     */
    @RequiresPermissions("client:faultCode:add")
    @Log(title = "车辆故障码", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增车辆故障码")
    public Result<String> add(@RequestBody FaultCodeSaveReq faultCodeSaveReq) {
        return toAjax(faultCodeService.save(FaultCode.saveBuild(faultCodeSaveReq)));
    }

    /**
     * 修改车辆故障码
     */
    @RequiresPermissions("client:faultCode:edit")
    @Log(title = "车辆故障码", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改车辆故障码")
    public Result<String> edit(@PathVariable Long id, @RequestBody FaultCodeEditReq faultCodeEditReq) {
        return toAjax(faultCodeService.updateById(FaultCode.editBuild(id,faultCodeEditReq)));
    }

    /**
     * 删除车辆故障码
     */
    @RequiresPermissions("client:faultCode:remove")
    @Log(title = "车辆故障码", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除车辆故障码")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(faultCodeService.removeBatchByIds(ids));
    }
}
